package org.rcisoft.wechat;

import me.chanjar.weixin.common.bean.WxJsapiSignature;
import me.chanjar.weixin.common.exception.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.kefu.WxMpKefuMessage;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.core.result.Result;
import org.rcisoft.core.result.ResultCode;
import org.rcisoft.wechat.service.WxPortalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 网页授权微信回调接口
 *
 * @author David
 */
@Controller
@RequestMapping("/wechat")
public class WechatRedirectController {

    @Resource
    private WxPortalService service;

    @Autowired
    private WxMpService wxService;

    @RequestMapping(value = {"/index"})
    public String index(String code) {

        try {
            WxMpUser wxUser = this.service.oauth2UserInfo(code);
            System.out.println("微信返回的code: " + code);
            System.out.println("WxPortalController授权完毕后获取到的OpenId是：" + wxUser.getOpenId());
            return "redirect:http://weega.cn.tunnel.qydev.com/login.html?openId=" + wxUser.getOpenId();
        } catch (Exception exception) {
            exception.printStackTrace();
            return "redirect:http://weega.cn.tunnel.qydev.com/error.html";
        }
    }

    @GetMapping(value = {"/getConfig"})
    @ResponseBody
    public Map<String, Object> getConfig(String url) {
        try {
            WxJsapiSignature wxJsapiSignature = service.getJsApiTicket(url);
            Map<String, Object> map = new HashMap<>(4);
            map.put("timestamp", wxJsapiSignature.getTimestamp());
            map.put("nonceStr", wxJsapiSignature.getNonceStr());
            map.put("signature", wxJsapiSignature.getSignature());
            map.put("appId", wxJsapiSignature.getAppId());
            return map;
        } catch (WxErrorException e) {
            e.printStackTrace();
        }
        return null;
    }

    @PostMapping(value = {"/sendMessage"})
    @ResponseBody
    public Result sendMessage(String message, String openId) {
        Result result = new Result();
        WxMpKefuMessage wxMpKefuMessage = WxMpKefuMessage
                .TEXT()
                .toUser(openId)
                .content(message)
                .build();
        // 设置消息的内容等信息
        boolean flag;
        try {
            flag = service.getKefuService().sendKefuMessage(wxMpKefuMessage);
        } catch (WxErrorException e) {
            e.printStackTrace();
            flag = false;
        }
        if(flag) {
            result.setCode(ResultCode.SUCCESS);
        } else {
            result.setCode(ResultCode.FAIL);
        }

        return result;
    }
}
